@@ -1,15 +1,15 @@
 import functools
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Optional
 
 
-def rgetattr(obj: Any, attr: str, *, default: Any = None):
-    def _getattr(obj, attr):
+def rgetattr(obj: Any, attr: str, *, default: Any = None) -> Any:
+    def _getattr(obj: Any, attr: Any) -> Any:
         return getattr(obj, attr, default)
 
     return functools.reduce(_getattr, [obj] + attr.split("."))
 
 
-def filter_payload(exclude: List[Any] = None, **kwargs) -> Dict[Any, Any]:
+def filter_payload(exclude: Optional[List[str]] = None, **kwargs: Any) -> Dict[Any, Any]:
     """
     Generate payload
     Usage: payload = generate_payload(**locals(), exclude=['foo'])
